@@ -1,6 +1,6 @@
 % STK_INIT initializes the STK
 %
-% CALL: stk_init()
+% CALL: stk_init ()
 %
 % STK_INIT sets paths and environment variables
 
@@ -126,15 +126,14 @@ end % function
 
 function stk_init__munlock ()
 
-filenames = { ...
-    'isoctave', ...
-    'stk_optim_fmincon', ...
-    'stk_options_set', ...
-    'stk_parallel_engine_set'};
+filenames = {                 ...
+    'stk_optim_fmincon',      ...
+    'stk_options_set',        ...
+    'stk_parallel_engine_set' };
 
 for i = 1:(length (filenames))
     name = filenames{i};
-    if mislocked (name),
+    if mislocked (name)
         munlock (name);
     end
 end
@@ -146,20 +145,19 @@ function stk_init__clear_persistents ()
 
 stk_init__munlock ();
 
-filenames = { ...
-    'isoctave', ...
-    'stk_disp_progress', ...
-    'stk_gausscov_iso', ...
-    'stk_gausscov_aniso', ...
-    'stk_materncov_aniso', ...
-    'stk_materncov_iso', ...
-    'stk_materncov32_aniso', ...
-    'stk_materncov32_iso', ...
-    'stk_materncov52_aniso', ...
-    'stk_materncov52_iso', ...
-    'stk_optim_fmincon', ...
-    'stk_options_set', ...
-    'stk_parallel_engine_set'};
+filenames = {                 ...
+    'stk_disp_progress',      ...
+    'stk_gausscov_iso',       ...
+    'stk_gausscov_aniso',     ...
+    'stk_materncov_aniso',    ...
+    'stk_materncov_iso',      ...
+    'stk_materncov32_aniso',  ...
+    'stk_materncov32_iso',    ...
+    'stk_materncov52_aniso',  ...
+    'stk_materncov52_iso',    ...
+    'stk_optim_fmincon',      ...
+    'stk_options_set',        ...
+    'stk_parallel_engine_set' };
 
 for i = 1:(length (filenames))
     clear (filenames{i});
@@ -173,7 +171,7 @@ function stk_init__addpath (root)
 path = stk_init__genpath (root);
 
 % Check for missing directories
-for i = 1:length (path),
+for i = 1:length (path)
     if ~ exist (path{i}, 'dir')
         error (sprintf (['Directory %s does not exist.\n' ...
             'Is there a problem in stk_init__genpath ?'], path{i}));
@@ -194,20 +192,21 @@ function path = stk_init__genpath (root)
 path = {};
 
 % main function folders
-path = [path {...
+path = [path {                           ...
     fullfile(root, 'arrays'            ) ...
     fullfile(root, 'arrays', 'generic' ) ...
     fullfile(root, 'core'              ) ...
     fullfile(root, 'covfcs'            ) ...
     fullfile(root, 'covfcs', 'rbf'     ) ...
     fullfile(root, 'lm'                ) ...
-    fullfile(root, 'paramestim'        ) ...
+    fullfile(root, 'param', 'classes'  ) ...
+    fullfile(root, 'param', 'estim'    ) ...
     fullfile(root, 'sampling'          ) ...
     fullfile(root, 'utils'             ) }];
 
 % 'misc' folder and its subfolders
 misc = fullfile (root, 'misc');
-path = [path {...
+path = [path {                 ...
     fullfile(misc, 'design'  ) ...
     fullfile(misc, 'dist'    ) ...
     fullfile(misc, 'distrib' ) ...
@@ -221,33 +220,13 @@ path = [path {...
     fullfile(misc, 'text'    ) }];
 
 % folders that contain examples
-path = [path {...
+path = [path {                                             ...
     fullfile(root, 'examples', '01_kriging_basics'       ) ...
     fullfile(root, 'examples', '02_design_of_experiments') ...
     fullfile(root, 'examples', '03_miscellaneous'        ) ...
     fullfile(root, 'examples', 'datasets'                ) ...
     fullfile(root, 'examples', 'test_functions'          ) }];
 
-% Fix a problem with private folders in Octave 3.2.x
-%   (add private folders to the path to make STK work...)
-if (exist ('OCTAVE_VERSION', 'builtin') == 5)
-    v = version;
-    if strcmp (v(1:4), '3.2.')
-        test_path = [path {...
-            fullfile(root, 'arrays', '@stk_dataframe') ...
-            fullfile(root, 'arrays', '@stk_factorialdesign') ...
-            fullfile(root, 'core', '@stk_kreq_qr')}];
-        private_path = {};
-        for i = 1:(length (test_path))
-            p = fullfile (test_path{i}, 'private');
-            if exist (p, 'dir')
-                private_path = [private_path {p}];
-            end
-        end
-        path = [path private_path];
-    end
-end
-
 end % function
 
 
@@ -285,27 +264,6 @@ end % function
 
 function s = escape_regexp (s)
 
-% For backward compatibility with Octave 3.2.x, we cannot use regexprep here:
-%
-%    s = regexprep (s, '([\+\.\\])', '\\$1');
-%
-% Indeed, compare the results with Octave 3.8.x
-%
-%    >> regexprep ('2.2.0', '(\.)', '\$1')
-%    ans = 2$12$10
-%
-%    >> regexprep ('2.2.0', '(\.)', '\\$1')
-%    ans = 2\.2\.0
-%
-% and those with Octave 3.2.4
-%
-%    >> regexprep ('2.2.0', '(\.)', '\$1')
-%    ans = 2\.2\.0
-%
-%    >> regexprep ('2.2.0', '(\.)', '\\$1')
-%    ans = 2\\.2\\.0
-%
-
 s = strrep (s, '\', '\\');
 s = strrep (s, '+', '\+');
 s = strrep (s, '.', '\.');
@@ -324,9 +282,6 @@ end
 
 opts = {root, mole_dir, do_addpath, prune_unused};
 
-% isoctave
-install_mole_function ('isoctave', opts{:});
-
 % Provide missing octave functions for Matlab users
 % TODO: extract functions that are REALLY needed in separate directories
 %       and get rid of the others !
@@ -383,7 +338,7 @@ if (isempty (w)) || (~ isempty (strfind (w, root)))  % if the function is absent
     if exist (function_dir, 'dir') && exist (function_mfile, 'file')
         
         % fprintf ('[MOLE]  Providing function %s\n', function_name);
-        if do_addpath,
+        if do_addpath
             addpath (function_dir);
         end
         
